@@ -62,8 +62,21 @@ def _cancel_tasks(loop, tasks):
     log.info('Cleaning up after %d tasks.', len(tasks))
     gathered = asyncio.gather(*tasks, loop=loop, return_exceptions=True)
     gathered.cancel()
-    gathered.add_done_callback(lambda fut: loop.stop())
 
+    def stop_and_silence(fut):
+        loop.stop()
+        try:
+            fut.result()
+        except asyncio.CancelledError:
+            pass
+        except Exception as e:
+            loop.call_exception_handler({
+                'message': 'Unhandled exception during Client.run shutdown.',
+                'exception': e,
+                'future': fut
+            })
+
+    gathered.add_done_callback(stop_and_silence)
     while not gathered.done():
         loop.run_forever()
 
@@ -550,16 +563,18 @@ class Client:
         is_windows = sys.platform == 'win32'
         loop = self.loop
         if not is_windows:
-            loop.add_signal_handler(signal.SIGINT, self._do_cleanup)
-            loop.add_signal_handler(signal.SIGTERM, self._do_cleanup)
+            loop.add_signal_handler(signal.SIGINT, lambda: loop.stop())
+            loop.add_signal_handler(signal.SIGTERM, lambda: loop.stop())
+
+        future = asyncio.ensure_future(self.start(*args, **kwargs), loop=loop)
+        future.add_done_callback(lambda f: loop.stop())
 
         try:
-            loop.run_until_complete(self.start(*args, **kwargs))
+            loop.run_forever()
         except KeyboardInterrupt:
             log.info('Received signal to terminate bot and event loop.')
         finally:
-            if is_windows:
-                self._do_cleanup()
+            self._do_cleanup()
 
     # properties
 
@@ -846,6 +861,10 @@ class Client:
             Using this, you will only receive :attr:`Guild.owner`, :attr:`Guild.icon`,
             :attr:`Guild.id`, and :attr:`Guild.name` per :class:`Guild`.
 
+        .. note::
+
+            This method is an API call. For general usage, consider :attr:`guilds` instead.
+
         All parameters are optional.
 
         Parameters
@@ -897,6 +916,10 @@ class Client:
             Using this, you will not receive :attr:`Guild.channels`, :class:`Guild.members`,
             :attr:`Member.activity` and :attr:`Member.voice` per :class:`Member`.
 
+        .. note::
+
+            This method is an API call. For general usage, consider :meth:`get_guild` instead.
+
         Parameters
         -----------
         guild_id: :class:`int`
@@ -1084,6 +1107,10 @@ class Client:
         with the user to get this information, however many operations
         do require that you do.
 
+        .. note::
+
+            This method is an API call. For general usage, consider :meth:`get_user` instead.
+
         Parameters
         -----------
         user_id: :class:`int`
